@@ -1,18 +1,18 @@
 /*
  * Copyright © 2015 Christian Persch
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This library is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 /**
@@ -29,12 +29,11 @@
 #include "vtemacros.h"
 #include "vteenums.h"
 #include "vteregex.h"
-#include "vtepcre2.h"
 
+#include "glib-glue.hh"
+#include "pcre2-glue.hh"
 #include "regex.hh"
 #include "vteregexinternal.hh"
-#include "glib-glue.hh"
-#include "cxx-utils.hh"
 
 #define IMPL(wrapper) (regex_from_wrapper(wrapper))
 
@@ -114,8 +113,8 @@ catch (...)
  * See man:pcre2pattern(3) for information
  * about the supported regex language.
  *
- * The regex will be compiled using %PCRE2_UTF and possibly other flags, in
- * addition to the flags supplied in @flags.
+ * The regex will be compiled using <literal>PCRE2_UTF</literal> and
+ * possibly other flags, in addition to the flags supplied in @flags.
  *
  * Returns: (transfer full): a newly created #VteRegex, or %NULL with @error filled in
  */
@@ -152,8 +151,8 @@ catch (...)
  * See man:pcre2pattern(3) for information
  * about the supported regex language.
  *
- * The regex will be compiled using %PCRE2_UTF and possibly other flags, in
- * addition to the flags supplied in @flags.
+ * The regex will be compiled using <literal>PCRE2_UTF</literal> and
+ * possibly other flags, in addition to the flags supplied in @flags.
  *
  * Returns: (transfer full): a newly created #VteRegex, or %NULL with @error filled in
  */
@@ -179,6 +178,8 @@ catch (...)
 /**
  * vte_regex_jit:
  * @regex: a #VteRegex
+ * @flags: PCRE2 JIT flags, or 0
+ * @error: (nullable): return location for a #GError, or %NULL
  *
  * If the platform supports JITing, JIT compiles @regex.
  *
@@ -225,7 +226,7 @@ _vte_regex_has_multiline_compile_flag(VteRegex *regex)
  * @flags: PCRE2 match flags
  * @error: (nullable): return location for a #GError, or %NULL
  *
- * See man:pcre2api(3) on pcre2_substitute() for more information.
+ * See man:pcre2api(3) and man:pcre2_substitute(3) for more information.
  *
  * Returns: (transfer full): the substituted string, or %NULL
  *   if an error occurred
